@@ -7,7 +7,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bug::Attachment;
-$BZ::Client::Bug::Attachment::VERSION = '4.4003';
+$BZ::Client::Bug::Attachment::VERSION = '4.4004';
 use parent qw( BZ::Client::API );
 
 use File::Basename qw/ basename /;
@@ -87,8 +87,8 @@ sub add {
 }
 
 sub update {
-    my(undef, $client, $params) = @_;
-    return _returns_array($client, 'Bug.update_attachment', $params, 'attachments');
+    my($class, $client, $params) = @_;
+    return $class->_returns_array($client, 'Bug.update_attachment', $params, 'attachments');
 }
 
 
@@ -218,7 +218,7 @@ BZ::Client::Bug::Attachment - Client side representation of an Attachment to a B
 
 =head1 VERSION
 
-version 4.4003
+version 4.4004
 
 =head1 SYNOPSIS
 
@@ -884,7 +884,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Dean Hamstad.
+This software is copyright (c) 2021 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
