@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::User;
-$BZ::Client::User::VERSION = '4.4003';
+$BZ::Client::User::VERSION = '4.4004';
 
 use parent qw( BZ::Client::API );
 
@@ -44,8 +44,8 @@ sub get {
 ## methods
 
 sub create {
-    my(undef, $client, $params) = @_;
-    return _create($client, 'User.create', $params);
+    my($class, $client, $params) = @_;
+    return $class->_create($client, 'User.create', $params);
 }
 
 sub update {
@@ -82,7 +82,7 @@ BZ::Client::User - Creates and edits user accounts in Bugzilla
 
 =head1 VERSION
 
-version 4.4003
+version 4.4004
 
 =head1 SYNOPSIS
 
@@ -502,7 +502,7 @@ Jochen Wiedmann <jochen.wiedmann@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Dean Hamstad.
+This software is copyright (c) 2021 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
